wasm

package
v0.9.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 4, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Rendered for js/wasm

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConnectWebSocket

func ConnectWebSocket(this js.Value, args []js.Value) interface{}

func DisconnectWebSocket

func DisconnectWebSocket(this js.Value, args []js.Value) interface{}

func GetDestination

func GetDestination(this js.Value, args []js.Value) interface{}

func GetDestinationPointer added in v0.9.0

func GetDestinationPointer() *destination.Destination

GetDestinationPointer returns the internal destination pointer.

func GetIdentity

func GetIdentity(this js.Value, args []js.Value) interface{}

func GetStats

func GetStats(this js.Value, args []js.Value) interface{}

func GetTransport added in v0.9.0

func GetTransport() *transport.Transport

GetTransport returns the internal transport pointer.

func InitReticulum

func InitReticulum(this js.Value, args []js.Value) interface{}

func IsConnected

func IsConnected(this js.Value, args []js.Value) interface{}

func RegisterJSFunctions

func RegisterJSFunctions()

RegisterJSFunctions registers the Reticulum WASM API to the JavaScript global scope.

func RequestPath added in v0.9.0

func RequestPath(this js.Value, args []js.Value) interface{}

func SendAnnounce

func SendAnnounce(appData []byte) interface{}

SendAnnounce is a generic function to send an announce

func SendAnnounceJS added in v0.9.0

func SendAnnounceJS(this js.Value, args []js.Value) interface{}

SendAnnounceJS is the JS-facing wrapper for SendAnnounce

func SendData added in v0.9.0

func SendData(destHash []byte, data []byte) interface{}

SendData is a generic function to send raw bytes to a destination

func SendDataJS added in v0.9.0

func SendDataJS(this js.Value, args []js.Value) interface{}

SendDataJS is the JS-facing wrapper for SendData

func SetAnnounceCallback added in v0.9.0

func SetAnnounceCallback(this js.Value, args []js.Value) interface{}

func SetPacketCallback added in v0.9.0

func SetPacketCallback(this js.Value, args []js.Value) interface{}

Types

This section is empty.

Jump to